==> nicotine_3.2.9.orig.tar.gz: nicotine-plus-3.2.9/TRANSLATORS.md <==
# Nicotine+ Translators

## Catalan
 - Maite Guix (2022)

## Chinese (Simplified)
 - hadwin (2022)

## Czech
 - burnmail123 (2021)

## Danish
 - mathsped (2003–2004)

## Dutch
 - Han Boetes (hboetes) (2021–2022)
 - Kenny Verstraete (2009)
 - nince78 (2007)
 - Ingmar K. Steen (Hyriand) (2003–2004)

## English
 - slook (2021–2022)
 - Han Boetes (hboetes) (2021–2022)
 - Mat (mathiascode) (2020–2022)
 - Michael Labouebe (gfarmerfr) (2016)
 - daelstorm (2004–2009)
 - Ingmar K. Steen (Hyriand) (2003–2004)

## Euskara
 - Julen (2006-2007)

## Finnish
 - Kari Viittanen (Kalevi) (2006–2007)

## French
 - Lisapple (2021–2022)
 - melmorabity (2021–2022)
 - m-balthazar (2020)
 - Michael Labouebe (gfarmerfr) (2016–2017)
 - Monsieur Poisson (2009–2010)
 - ManWell (2007)
 - zniavre (2007–2022)
 - systr (2006)
 - Julien Wajsberg (flashfr) (2003–2004)

## German
 - Han Boetes (hboetes) (2021–2022)
 - Meokater (2007)
 - (._.) (2007)
 - lippel (2004)
 - Ingmar K. Steen (Hyriand) (2003–2004)

## Hungarian
 - Szia Tomi (2022)
 - Nils (2009)
 - David Balazs (djbaloo) (2006–2020)

## Italian
 - Gabboxl (2022)
 - Gianluca Boiano (2020–2022)
 - nicola (2007)
 - dbazza (2003–2004)

## Latvian
 - Pagal3 (2022)

## Lithuanian
 - mantas (2020)
 - Žygimantas Beručka (2006–2009)

## Norwegian Bokmål
 - Allan Nordhøy (comradekingu) (2021)

## Polish
 - mariachini (2017–2022)
 - Amun-Ra (2007)
 - thine (2007)
 - Wojciech Owczarek (owczi) (2003–2004)

## Portuguese (Brazil)
 - Guilherme Santos (2022)
 - b1llso (2022)
 - Nicolas Abril (2021)
 - yyyyyyyan (2020)
 - Felipe Nogaroto Gonzalez (Suicide|Solution) (2006)

## Russian
 - AHOHNMYC (2022)
 - SnIPeRSnIPeR (2022)
 - Mehavoid (2021–2022)

## Slovak
 - Jozef Říha (2006–2008)

## Spanish (Chile)
 - MELERIX (2021–2022)
 - tagomago (2021–2022)
 - Strange (2021)
 - Silvio Orta (2007)
 - Dreslo (2003–2004)

## Spanish (Spain)
 - MELERIX (2021)
 - tagomago (2021–2022)
 - Strange (2021)
 - Silvio Orta (2007)
 - Dreslo (2003–2004)

## Swedish
 - mitramai (2021)
 - Markus Magnuson (alimony) (2003–2004)

## Turkish
 - Oğuz Ersen (2021–2022)

## Ukrainian
 - uniss2209 (2022)

==> nicotine_3.3.2.orig.tar.gz: nicotine-plus-3.3.2/TRANSLATORS.md <==
# Nicotine+ Translators

## Albanian
 - W L (2023)

## Arabic
 - ButterflyOfFire (2024)

## Catalan
 - Maite Guix (2022)

## Chinese (Simplified)
 - Bonislaw (2023)
 - hylau (2023)
 - hadwin (2022)

## Czech
 - burnmail123 (2021-2023)

## Danish
 - mathsped (2003–2004)

## Dutch
 - Han Boetes (hboetes) (2021–2023)
 - Kenny Verstraete (2009)
 - nince78 (2007)
 - Ingmar K. Steen (Hyriand) (2003–2004)

## English
 - slook (2021–2023)
 - Han Boetes (hboetes) (2021–2023)
 - Mat (mathiascode) (2020–2023)
 - Michael Labouebe (gfarmerfr) (2016)
 - daelstorm (2004–2009)
 - Ingmar K. Steen (Hyriand) (2003–2004)

## Esperanto
 - phlostically (2021)

## Estonian
 - PriitUring (2023)

## Euskara
 - Julen (2006–2007)

## Finnish
 - Kari Viittanen (Kalevi) (2006–2007)

## French
 - Saumon (2023)
 - subu_versus (2023)
 - zniavre (2007–2023)
 - Lisapple (2021–2022)
 - melmorabity (2021–2022)
 - m-balthazar (2020)
 - Michael Labouebe (gfarmerfr) (2016–2017)
 - Monsieur Poisson (2009–2010)
 - ManWell (2007)
 - systr (2006)
 - Julien Wajsberg (flashfr) (2003–2004)

## German
 - Han Boetes (hboetes) (2021–2023)
 - phelissimo_ (2023)
 - Meokater (2007)
 - (._.) (2007)
 - lippel (2004)
 - Ingmar K. Steen (Hyriand) (2003–2004)

## Hungarian
 - Szia Tomi (2022–2023)
 - Nils (2009)
 - David Balazs (djbaloo) (2006–2020)

## Italian
 - Gabboxl (2022–2023)
 - ms-afk (2023)
 - Gianluca Boiano (2020–2022)
 - nicola (2007)
 - dbazza (2003–2004)

## Latvian
 - Pagal3 (2022–2023)

## Lithuanian
 - mantas (2020)
 - Žygimantas Beručka (2006–2009)

## Norwegian Bokmål
 - Allan Nordhøy (comradekingu) (2021)

## Polish
 - Mariusz (mariachini) (2017–2023)
 - Amun-Ra (2007)
 - thine (2007)
 - Wojciech Owczarek (owczi) (2003–2004)

## Portuguese
 - ssantos (2023)
 - Vinícius Soares (2023)

## Portuguese (Brazil)
 - Havokdan (2022–2023)
 - Guilherme Santos (2022)
 - b1llso (2022)
 - Nicolas Abril (2021)
 - yyyyyyyan (2020)
 - Felipe Nogaroto Gonzalez (Suicide|Solution) (2006)

## Romanian
 - xslendix (2023)

## Russian
 - Kirill Feoktistov (SnIPeRSnIPeR) (2022–2023)
 - Mehavoid (2021–2023)
 - AHOHNMYC (2022)

## Slovak
 - Jozef Říha (2006–2008)

## Spanish (Chile)
 - MELERIX (2021–2023)
 - tagomago (2021–2022)
 - Strange (2021)
 - Silvio Orta (2007)
 - Dreslo (2003–2004)

## Spanish (Spain)
 - gallegonovato (2023)
 - MELERIX (2021–2023)
 - tagomago (2021–2022)
 - Strange (2021)
 - Silvio Orta (2007)
 - Dreslo (2003–2004)

## Swedish
 - mitramai (2021)
 - Markus Magnuson (alimony) (2003–2004)

## Turkish
 - Oğuz Ersen (2021–2023)

## Ukrainian
 - uniss2209 (2022)
